@@ -15,7 +15,7 @@ def read_genbank(file_path, output_format):
     :param output_format: OutputFormat class object for your desired output format
     :return: DNA entity
     """
-    parsed_genbank = list(SeqIO.parse(file_path, 'gb'))[0]
+    parsed_genbank = SeqIO.read(file_path, 'gb')
     dna_entity = convert_biopython_to_dnassembly(parsed_genbank, output_format)
 
     return dna_entity
